@@ -28,7 +28,7 @@ else:
 
 
 __all__ = ["tabulate", "tabulate_formats", "simple_separated_format"]
-__version__ = "0.7"
+__version__ = "0.7.1"
 
 
 Line = namedtuple("Line", ["begin", "hline", "sep", "end"])
@@ -102,7 +102,7 @@ def _mediawiki_row_with_attrs(separator, cell_values, colwidths, colaligns):
                   "decimal": 'align="right"| ' }
     # hard-coded padding _around_ align attribute and value together
     # rather than padding parameter which affects only the value
-    values_with_attrs = [' ' + alignment[a] + c + ' '
+    values_with_attrs = [' ' + alignment.get(a, '') + c + ' '
                          for c, a in zip(cell_values, colaligns)]
     colsep = separator*2
     return (separator + colsep.join(values_with_attrs)).rstrip()
@@ -110,7 +110,7 @@ def _mediawiki_row_with_attrs(separator, cell_values, colwidths, colaligns):
 
 def _latex_line_begin_tabular(colwidths, colaligns):
     alignment = { "left": "l", "right": "r", "center": "c", "decimal": "r" }
-    tabular_columns_fmt = "".join([alignment[a] for a in colaligns])
+    tabular_columns_fmt = "".join([alignment.get(a, "l") for a in colaligns])
     return "\\begin{tabular}{" + tabular_columns_fmt + "}\n\hline"
 
 
@@ -178,13 +178,20 @@ _table_formats = {"simple":
                               linebelow=Line("\\hline\n\\end{tabular}", "", "", ""),
                               headerrow=DataRow("", "&", "\\\\"),
                               datarow=DataRow("", "&", "\\\\"),
-                              padding=1, with_header_hide=None)}
+                              padding=1, with_header_hide=None),
+                  "tsv":
+                  TableFormat(lineabove=None, linebelowheader=None,
+                              linebetweenrows=None, linebelow=None,
+                              headerrow=DataRow("", "\t", ""),
+                              datarow=DataRow("", "\t", ""),
+                              padding=0, with_header_hide=None)}
 
 
 tabulate_formats = list(sorted(_table_formats.keys()))
 
 
 _invisible_codes = re.compile("\x1b\[\d*m")  # ANSI color codes
+_invisible_codes_bytes = re.compile(b"\x1b\[\d*m")  # ANSI color codes
 
 
 def simple_separated_format(separator):
@@ -196,7 +203,8 @@ def simple_separated_format(separator):
 
     """
     return TableFormat(None, None, None, None,
-                       headerrow=None, datarow=DataRow('', separator, ''),
+                       headerrow=DataRow('', separator, ''),
+                       datarow=DataRow('', separator, ''),
                        padding=0, with_header_hide=None)
 
 
@@ -331,7 +339,10 @@ def _padboth(width, s, has_invisible=True):
 
 def _strip_invisible(s):
     "Remove invisible ANSI color codes."
-    return re.sub(_invisible_codes, "", s)
+    if isinstance(s, _text_type):
+        return re.sub(_invisible_codes, "", s)
+    else:  # a bytestring
+        return re.sub(_invisible_codes_bytes, "", s)
 
 
 def _visible_width(s):
@@ -353,19 +364,24 @@ def _align_column(strings, alignment, minwidth=0, has_invisible=True):
     >>> list(map(str,_align_column(["12.345", "-1234.5", "1.23", "1234.5", "1e+234", "1.0e234"], "decimal")))
     ['   12.345  ', '-1234.5    ', '    1.23   ', ' 1234.5    ', '    1e+234 ', '    1.0e234']
 
+    >>> list(map(str,_align_column(['123.4', '56.7890'], None)))
+    ['123.4', '56.7890']
+
     """
     if alignment == "right":
         strings = [s.strip() for s in strings]
         padfn = _padleft
-    elif alignment in "center":
+    elif alignment == "center":
         strings = [s.strip() for s in strings]
         padfn = _padboth
-    elif alignment in "decimal":
+    elif alignment == "decimal":
         decimals = [_afterpoint(s) for s in strings]
         maxdecimals = max(decimals)
         strings = [s + (maxdecimals - decs) * " "
                    for s, decs in zip(strings, decimals)]
         padfn = _padleft
+    elif not alignment:
+        return strings
     else:
         strings = [s.strip() for s in strings]
         padfn = _padright
@@ -381,8 +397,8 @@ def _align_column(strings, alignment, minwidth=0, has_invisible=True):
 
 
 def _more_generic(type1, type2):
-    types = { _none_type: 0, int: 1, float: 2, _text_type: 4 }
-    invtypes = { 4: _text_type, 2: float, 1: int, 0: _none_type }
+    types = { _none_type: 0, int: 1, float: 2, _binary_type: 3, _text_type: 4 }
+    invtypes = { 4: _text_type, 3: _binary_type, 2: float, 1: int, 0: _none_type }
     moregeneric = max(types.get(type1, 4), types.get(type2, 4))
     return invtypes[moregeneric]
 
@@ -426,8 +442,10 @@ def _format(val, valtype, floatfmt, missingval=u""):
     if val is None:
         return missingval
 
-    if valtype in [int, _binary_type, _text_type]:
+    if valtype in [int, _text_type]:
         return u"{0}".format(val)
+    elif valtype is _binary_type:
+        return _text_type(val, "ascii")
     elif valtype is float:
         return format(float(val), floatfmt)
     else:
@@ -439,6 +457,8 @@ def _align_header(header, alignment, width):
         return _padright(width, header)
     elif alignment == "center":
         return _padboth(width, header)
+    elif not alignment:
+        return u"{0}".format(header)
     else:
         return _padleft(width, header)
 
@@ -565,8 +585,8 @@ def tabulate(tabular_data, headers=[], tablefmt="simple",
     the values properly. By default it aligns decimal points of the
     numbers (or flushes integer numbers to the right), and flushes
     everything else to the left. Possible column alignments
-    (`numalign`, `stralign`) are: right, center, left, decimal (only
-    for `numalign`).
+    (`numalign`, `stralign`) are: "right", "center", "left", "decimal"
+    (only for `numalign`), and None (to disable alignment).
 
 
     Table formats
